@@ -2,13 +2,13 @@
 
 # The return code will capture an error from ANY of the functions in the pipe
 set -o pipefail
-make -j2 2>&1 | tee build.log | grep "Building"
+make VERBOSE=1 -j2 2>&1 | tee build.log | grep "Building"
 RESULT=$?
 
 if [ $RESULT -eq 0 ]; then
   echo build succeeded
 else
   echo build failed
-  tail -500 build.log
+  cat build.log
   exit 1
 fi
