@@ -1,8 +1,36 @@
 #!/usr/bin/perl
 
+#
+# @BEGIN LICENSE
+#
+# Psi4: an open-source quantum chemistry software package
+#
+# Copyright (c) 2007-2017 The Psi4 Developers.
+#
+# The copyrights for code used from other parties are included in
+# the corresponding files.
+#
+# This file is part of Psi4.
+#
+# Psi4 is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, version 3.
+#
+# Psi4 is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with Psi4; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+# @END LICENSE
+#
+
 my $DriverPath = "";
 if ($#ARGV == 0) { $DriverPath = $ARGV[0] . "/"; }
-my $BasisFolder = $DriverPath . "../../share/basis/";
+my $BasisFolder = $DriverPath . "../../psi4/share/psi4/basis/";
 
 # Create a HTML table for the Trac page
 #open(HTML_OUT,">psi4bases.html") or die "I can't write to psi4bases.html\n";
@@ -206,6 +234,14 @@ foreach $b (@HGBS) { if ($b =~ /^def2-.*\.gbs$/) { push(@HAHLRICHS, $b); } }
 foreach $gbs (@HAHLRICHS) { htmlline($gbs); }
 printf "Auto-documenting basis set files %s\n", "Ahlrichs";
 
+#print HTML_OUT "<tr><td><big><b>Jensen</b></big></td></tr>\n\n";
+#print LATEX_OUT "\n\n\\\\*\n{\\normalsize\\textbf{Jensen}} \\\\*\n";
+printf RST_OUT "   $divdash\n   | %-65s | %6s | %501s |\n   $divdash\n", "**Jensen**", "", "";
+@HJENSEN = ();
+foreach $b (@HGBS) { if ($b =~ /^.*pc.*seg.*\.gbs$/) { push(@HJENSEN, $b); } }
+foreach $gbs (@HJENSEN) { htmlline($gbs); }
+printf "Auto-documenting basis set files %s\n", "Jensen";
+
 #print HTML_OUT "<tr><td><big><b>Dunning D&#950;</b></big></td></tr>\n\n";
 #print LATEX_OUT "\n\n\\\\*\n{\\normalsize\\textbf{Dunning D\$\\bm\\zeta\$}} \\\\*\n";
 printf RST_OUT "   $divdash\n   | %-65s | %6s | %501s |\n   $divdash\n", "**Dunning D-zeta**", "", "";
@@ -311,7 +347,7 @@ foreach $b (@HGBS) { if ($b =~ /^feb-cc-.*6pd.*\.gbs$/) { push(@H6DUNNING, $b);
 foreach $gbs (@H6DUNNING) { htmlline($gbs); }
 printf "Auto-documenting basis set files %s\n", "Dunning 6-zeta";
 
-@HCATBASIS = (@HPOPLE,@HAHLRICHS,@HDDUNNING,@HTDUNNING,@HQDUNNING,@H5DUNNING,@H6DUNNING);
+@HCATBASIS = (@HPOPLE,@HAHLRICHS,@HJENSEN,@HDDUNNING,@HTDUNNING,@HQDUNNING,@H5DUNNING,@H6DUNNING);
 
 @HREST = ();
 foreach my $item (@HGBS) {
